"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var types = require("babel-types");
var nejmap_1 = require("nejm/nejmap");
var textDeps = /^text!|^regular!|^json!/i;
/**
 * 分析nej模块的依赖
 *
 * @param source 依赖路径
 *
 * NEJ 依赖举例
 * 1. base/util                 导入 nej 模块
 * 2. pro/extend/util
 *    {pro}/extend/util.js      导入 pro 文件夹下的模块
 * 3. text!/path/to/file.css    导入文本文件
 * 4.
 */
var analyisDeps = function (source) {
    var isNej = nejmap_1.source2name[source] !== undefined;
    var isText = textDeps.test(source);
    var moduleNameRe = /^{(.*?)}/;
    var moduleName = '';
    if (!(isNej || isText) && (source.startsWith('{') || !source.endsWith('.js'))) {
        var result = source.match(moduleNameRe);
        if (result) {
            moduleName = result[1];
        }
        else {
            moduleName = source.split('/')[0];
        }
    }
    return {
        source: source,
        isNej: isNej,
        isText: isText,
        moduleName: moduleName
    };
};
/**
 * 获取nej模块依赖
 *
 * @param path
 */
function fetchNEJdependences(path) {
    var fnBody;
    var deps = [];
    var custormModule = [];
    var textModule = [];
    var nejModule = [];
    var visitor = {
        CallExpression: function (_a) {
            var node = _a.node;
            if (node.callee.name === 'define') {
                node.arguments[0].elements.forEach(function (_a) {
                    var value = _a.value;
                    deps.push(analyisDeps(value));
                });
                if (types.isFunctionExpression(node.arguments[1])) {
                    fnBody = node.arguments[1].body.body;
                    node.arguments[1].params.forEach(function (param, i) {
                        deps[i]['name'] = param.name;
                    });
                }
            }
        }
    };
    path.traverse(visitor);
    deps.forEach(function (dep) {
        if (dep.isNej) {
            nejModule.push(dep);
        }
        else if (dep.isText) {
            textModule.push(dep);
        }
        else {
            custormModule.push(dep);
        }
    });
    return {
        custormModule: custormModule,
        textModule: textModule,
        nejModule: nejModule,
        rawDeps: deps,
        fnBody: fnBody
    };
}
exports.fetchNEJdependences = fetchNEJdependences;
//# sourceMappingURL=index.js.map